@@ -24,6 +24,10 @@ labkey.setDefaults <- function(apiKey="", baseUrl="", email="", password="")
     # with any reset of the defaults, clear the httr session cookies (https://stackoverflow.com/questions/39979393/how-to-remove-cookies-preserved-by-httrget)
     if (!is.null(.lkdefaults$baseUrl)) {
         handle_reset(.lkdefaults$baseUrl)
+
+        # Issue 50592: clear the CSRF token cache as well
+        urlBase = labkey.getBaseUrl()
+        .lkcsrf[[urlBase]] = NULL
     }
 
     if (baseUrl != "")
